@@ -1,5 +1,6 @@
 import aiohttp
 import asyncio
+import contextlib
 import sys
 from .utils import *
 from .arguments import main as arguments_main
@@ -11,14 +12,23 @@ async def main() -> int:
 
     retval = 0
 
-    headers, urls = arguments_main()
+    headers, cookies, urls, max_downloads = arguments_main()
+
+    if max_downloads is not None:
+        sem = asyncio.Semaphore(max_downloads)
+    else:
+        sem = contextlib.nullcontext()
 
     timeout = aiohttp.ClientTimeout(total=None)
-    async with aiohttp.ClientSession(headers=headers, timeout=timeout) as session:
+    async with aiohttp.ClientSession(
+        headers=headers,
+        cookies=cookies,
+        timeout=timeout
+    ) as session:
         workers = []
 
         for idx, url in enumerate(urls):
-            workers.append(worker(idx, url, session))
+            workers.append(worker(idx, url, session, sem))
 
         results = await asyncio.gather(*workers, return_exceptions=True)
 
@@ -37,5 +47,4 @@ def cli():
 
 
 if __name__ == "__main__":
-    print_ketter_banner()
-    sys.exit(asyncio.run(main()))
+    cli()
